@@ -16,6 +16,7 @@ APPS_DIR = ROOT_DIR.path("backend")
 # django-sso-app
 from django_sso_app.settings import *
 
+
 READ_DOT_ENV_FILE = env.bool("DJANGO_READ_DOT_ENV_FILE", default=False)
 if READ_DOT_ENV_FILE:
     # OS environment variables take precedence over variables from .env
@@ -65,7 +66,10 @@ EMAILS_DOMAIN = env('EMAILS_DOMAIN', default=APP_DOMAIN) # domain name specified
 EMAILS_SITE_NAME = env('EMAILS_SITE_NAME', default=COOKIE_DOMAIN) # site name specified in email templates
 GOOGLE_API_KEY = env('GOOGLE_API_KEY', default='undefined')
 GOOGLE_MAPS_API_VERSION = env('GOOGLE_MAPS_API_VERSION', default='3.34')
-GOOGLE_ANALYTICS_TRACKING_ID = env('GOOGLE_ANALYTICS_TRACKING_ID', default='undefined')
+GOOGLE_ANALYTICS_TRACKING_ID = env('GOOGLE_ANALYTICS_TRACKING_ID', default='')
+RAVEN_JS_DSN = env('RAVEN_JS_DSN',default='')
+MAPBOX_ACCESSTOKEN = env('MAPBOX_ACCESSTOKEN',
+                         default='pk.eyJ1IjoibWFwYm94IiwiYSI6ImNpejY4NXVycTA2emYycXBndHRqcmZ3N3gifQ.rJcFIG214AriISLbB6B5aw')
 
 # languages
 from .languages import *
@@ -74,11 +78,12 @@ from .languages import *
 META_DESCRIPTION = env('META_DESCRIPTION', default=APP_DOMAIN)
 META_SITE_PROTOCOL = ACCOUNT_DEFAULT_HTTP_PROTOCOL
 META_USE_SITES = True
-# META_SITE_DOMAIN = APP_DOMAIN
-META_SITE_NAME = APP_DOMAIN
+META_SITE_DOMAIN = APP_DOMAIN
+META_SITE_NAME = COOKIE_DOMAIN
 META_USE_OG_PROPERTIES = True
 META_USE_TWITTER_PROPERTIES = True
-META_USE_GOOGLEPLUS_PROPERTIES = True
+META_USE_GOOGLEPLUS_PROPERTIES = False
+META_USE_TITLE_TAG = False
 
 
 # DATABASES
@@ -271,8 +276,12 @@ TEMPLATES = [
 
                 # django-sso-app
                 'django_sso_app.core.context_processors.django_sso_app_context',
+
+                # extra
                 'django_sso_app.backend.context_processors.get_repository_rev',
-                'django_sso_app.backend.context_processors.get_meta_info',
+                'django_sso_app.backend.context_processors.django_meta',
+                'django_sso_app.backend.context_processors.google_api_settings',
+                'django_sso_app.backend.context_processors.raven_js_dsn_settings',
             ],
         },
     }
