@@ -15,11 +15,11 @@ from django.utils.translation import gettext_lazy as _
 from django.core.exceptions import SuspiciousOperation
 
 from allauth.account.adapter import DefaultAccountAdapter
-from allauth.account.models import EmailAddress
 from allauth.account import app_settings as allauth_app_settings
 
 from .mixins import TryAuthenticateMixin
 from .utils import set_session_key, check_user_can_login
+from .apps.emails.models import EmailAddress
 from .apps.devices.models import Device
 from .apps.devices.utils import get_request_device
 from .apps.services.models import Subscription
@@ -118,7 +118,7 @@ class AccountAdapter(DefaultAccountAdapter, TryAuthenticateMixin):
         logger.debug('adapter logout, user logged out, setting flags')
         # print(inspect.stack()[1].function)
         try:
-            _device = get_request_device(request)
+            request_device = get_request_device(request)
 
         except Exception as e:
             logger.debug('no device on request because of "{}"'.format(e))
@@ -129,19 +129,18 @@ class AccountAdapter(DefaultAccountAdapter, TryAuthenticateMixin):
         super(AccountAdapter, self).logout(request)
 
         if not is_authenticated(request.user):
-            deleted_devices = self.remove_all_user_profile_devices(logging_out_user)
+            if app_settings.LOGOUT_DELETES_ALL_PROFILE_DEVICES:
+                deleted_devices = self.remove_all_user_profile_devices(logging_out_user)
+            else:
+                deleted_devices = self.remove_user_profile_device(request_device)
+
             logger.info('({}) devices deleted for user "{}"'.format(deleted_devices, logging_out_user))
 
     def confirm_email(self, request, email_address):
-        """
-        Marks the email address as confirmed on the db
-        """
-        email_address.verified = True
+        super(AccountAdapter, self).confirm_email(request, email_address)
 
-        # email_address.set_as_primary(conditional=True)
-        email_address.set_as_primary(conditional=False) # allauth originally won't swap email addresses
-
-        email_address.save()
+        # one email per user
+        email_address.user.emailaddress_set.exclude(email=email_address).delete()
 
     def set_password(self, user, password):
         user.set_password(password)
