@@ -11,14 +11,15 @@ from rest_framework.views import APIView
 from rest_framework.permissions import IsAuthenticated, AllowAny
 from rest_framework.response import Response
 
-from allauth.account.models import EmailAddress
 from allauth.account.views import INTERNAL_RESET_URL_KEY, INTERNAL_RESET_SESSION_KEY
 from allauth.account.forms import UserTokenForm
 from allauth.utils import get_request_param
 from allauth.account.adapter import get_adapter
 
+from ..apps.emails.models import EmailAddress
 from ..apps.users.serializers import SuccessfullLoginResponseSerializer, SuccessfullLogoutResponseSerializer
 from ..apps.passepartout.utils import get_passepartout_login_redirect_url
+from ..tokens.utils import renew_response_jwt
 from ..permissions import is_authenticated
 from ..utils import set_session_key, get_session_key, get_random_fingerprint
 from .. import views as django_sso_app_views
