@@ -24,14 +24,16 @@ adapter = get_adapter()
 @receiver(pre_save, sender=Device)
 def create_device_apigw_jwt(sender, instance, **kwargs):
     profile = instance.profile
-
     apigateway_consumer_id = get_profile_apigw_consumer_id(profile)
+
     logger.info('Profile "{}" has apigateway_consumer_id "{}"'.format(profile, apigateway_consumer_id))
 
     if instance._state.adding:
-        logger.info('Creating apigw JWT for Device "{}"'.format(instance))
+        device = instance
 
-        status_code, r1 = create_apigw_consumer_jwt(instance.profile)
+        logger.info('Creating apigw JWT for Device "{}"'.format(device))
+
+        status_code, r1 = create_apigw_consumer_jwt(device.profile)
         if status_code != 201:
             # delete_apigw_consumer(username)
             logger.error(
@@ -40,21 +42,22 @@ def create_device_apigw_jwt(sender, instance, **kwargs):
             raise Exception(
                 'Error ({}) creating apigw consumer jwt'.format(status_code))
 
-        instance.apigw_jwt_id = r1.get('id')
-        instance.apigw_jwt_key = r1.get('key')
-        instance.apigw_jwt_secret = r1.get('secret')
+        device.apigw_jwt_id = r1.get('id')
+        device.apigw_jwt_key = r1.get('key')
+        device.apigw_jwt_secret = r1.get('secret')
 
 
 @receiver(pre_delete, sender=Device)
 def delete_device_api_jwt(sender, instance, **kwargs):
-    logger.info('Deleting apigw JWT for Device "{}", jwt_id: "{}"'.format(instance, instance.apigw_jwt_id))
+    device = instance
+    logger.info('Deleting apigw JWT for Device "{}", jwt_id: "{}"'.format(device, device.apigw_jwt_id))
 
-    status_code, r1 = delete_apigw_consumer_jwt(instance.profile, instance.apigw_jwt_id)
+    status_code, r1 = delete_apigw_consumer_jwt(device.profile, device.apigw_jwt_id)
     logger.info('Kong JWT deleted ({0}), {1}'.format(status_code, r1))
     if status_code >= 300:
         if status_code != 404:
             # delete_apigw_consumer(username)
-            logger.error('Error ({}) Deleting apigw JWT for Device "{}", "{}"'.format(status_code, instance, r1))
+            logger.error('Error ({}) Deleting apigw JWT for Device "{}", "{}"'.format(status_code, device, r1))
 
             raise Exception(
                 "Error deleting apigw consumer jwt, {}".format(status_code))
@@ -65,10 +68,11 @@ def delete_device_api_jwt(sender, instance, **kwargs):
 def delete_apigw_user_consumer(sender, instance, **kwargs):
     user = instance.user
 
-    if not is_staff(user):
-        logger.info('Profile "{}" will be deleted, removing api gateway consumer'.format(instance))
+    if not user.is_superuser:
+        profile = instance
+        logger.info('Profile "{}" will be deleted, removing api gateway consumer'.format(profile))
 
-        status_code, r1 = delete_apigw_consumer(instance)
+        status_code, r1 = delete_apigw_consumer(profile)
         logger.info('Api gateway consumer deletion: ({0}), {1}'.format(status_code, r1))
 
         if status_code >= 300:
@@ -76,7 +80,7 @@ def delete_apigw_user_consumer(sender, instance, **kwargs):
                 # delete_apigw_consumer(username)
                 logger.error(
                     'Error ({0}) Deleting apigw consumer for User {1}, {2}'.format(
-                        status_code, instance, r1))
+                        status_code, profile, r1))
                 raise Exception(
                     "Error deleting apigw consumer, {}".format(status_code))
 
@@ -88,8 +92,9 @@ def signal_handler_when_profile_is_added_to_or_removed_from_group(action, instan
 
     if model == Group and instance.__class__ == Profile:
         user = instance.user
+        profile = instance
 
-        if not is_staff(user):
+        if not user.is_superuser:
 
             if action == 'pre_add':
                 for pk in pk_set:
@@ -102,7 +107,7 @@ def signal_handler_when_profile_is_added_to_or_removed_from_group(action, instan
                         logger.info('api gateway acl goup created {}, {}'.format(status_code, resp))
 
                         if not is_loaddata:
-                            instance.update_rev(True)
+                            profile.update_rev(True)
                     else:
                         logger.exception('error ({}) creating api gateway acl group'.format(status_code))
 
@@ -117,7 +122,6 @@ def signal_handler_when_profile_is_added_to_or_removed_from_group(action, instan
                         logger.info('"{}" DELETED, updating profile sso_rev'.format(group))
 
                         if not is_loaddata:
-                            instance.update_rev(True)
+                            profile.update_rev(True)
                     else:
                         logger.exception('error ({}) creating api gateway acl group'.format(status_code))
-
