@@ -4,7 +4,6 @@ import logging
 # pyximport.install()
 
 from ...functions import lists_differs
-from .models import Group
 
 logger = logging.getLogger('django_sso_app.core.apps.groups')
 
@@ -15,10 +14,5 @@ def update_profile_groups(profile, groups_list):
     if lists_differs(previous_groups_list, groups_list):
         logger.info('groups updated for "{}"'.format(profile))
 
-        for group in groups_list:
-            g, _created = Group.objects.get_or_create(name=group)
-            if _created:
-                logger.info('group "{}" created'.format(g))
-
-            profile.groups.add(g)
-
+        for group_name in groups_list:
+            profile.add_to_group(group_name)
