@@ -38,6 +38,9 @@ def get_or_create_user_profile(user, ProfileModel, initials=None, commit=True):
     except ProfileModel.DoesNotExist:
         logger.info('User "{}" has no profile, creating one'.format(user))
 
+        # set creating flag to disable rev update
+        # setattr(user, '__django_sso_app__creating', True)
+
         sso_id = getattr(user, '__django_sso_app__profile__sso_id', None)
         if sso_id is not None:
             sso_rev = getattr(user, '__django_sso_app__profile__sso_rev', 0)
@@ -48,7 +51,6 @@ def get_or_create_user_profile(user, ProfileModel, initials=None, commit=True):
 
         if is_test_user(user):
             logger.info('User "{}" is TEST_USER, setting sso_id="{}"'.format(user, app_settings.TEST_USER_USERNAME))
-            setattr(user, '__django_sso_app__creating', True)
 
             profile.sso_id = app_settings.TEST_USER_USERNAME
 
