@@ -5,17 +5,18 @@ from http.cookies import SimpleCookie
 from django.contrib.auth import get_user_model
 from django.test import Client
 from django.urls import reverse
-from rest_framework import status
 from django.contrib.auth.hashers import make_password
 from django.test import TestCase, Client
+from django.test.utils import override_settings
+
+from rest_framework import status
 from allauth.account.adapter import get_adapter
-from allauth.account.models import EmailAddress
 from rest_framework.authtoken.models import Token
 
 from django_sso_app.core import app_settings
 
 from django_sso_app.core.apps.profiles.models import Profile
-from django_sso_app.core.apps.groups.models import Group
+from django_sso_app.core.apps.emails.models import EmailAddress
 
 User = get_user_model()
 
