@@ -15,7 +15,7 @@ SEED = int(base64.b16encode(bytes(get_random_secret_key(), 'utf-8')), 16)
 seed(SEED)
 
 
-def set_cookie(response, key, value, days_expire=None):
+def set_cookie(response, key, value, days_expire=None, secure=True):
     """
     Sets response auth cookie
 
@@ -23,6 +23,7 @@ def set_cookie(response, key, value, days_expire=None):
     :param key:
     :param value:
     :param days_expire:
+    :param secure:
     :return:
     """
     if days_expire is None:
@@ -35,7 +36,7 @@ def set_cookie(response, key, value, days_expire=None):
 
     response.set_cookie(key, value, max_age=None, expires=expires, path='/',
                         domain=app_settings.COOKIE_DOMAIN,
-                        secure=None,
+                        secure=secure,
                         httponly=app_settings.COOKIE_HTTPONLY)
 
 
