@@ -37,7 +37,7 @@ class DjangoSsoAppBaseViewMixin():
         if is_authenticated(request.user):
             if not request.user.is_superuser:
                 token = get_session_key(request, '__django_sso_app__jwt_token')
-                set_cookie(response, app_settings.JWT_COOKIE_NAME, token, None)
+                set_cookie(response, app_settings.JWT_COOKIE_NAME, token)
 
         return response
 
